# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`haproxy_consul::dns_on_53`](#haproxy_consuldns_on_53): Forward port 53 to Consul DNS on port 8600
* [`haproxy_consul::puppet_ca_files`](#haproxy_consulpuppet_ca_files): Setup connection validation via Puppet CA

### Defined types

* [`haproxy_consul::resolver`](#haproxy_consulresolver): Generates a HAProxy resolver backed by Consul
* [`haproxy_consul::server_template`](#haproxy_consulserver_template): Creates both a HAProxy listen and balancemenber resource

## Classes

### <a name="haproxy_consuldns_on_53"></a>`haproxy_consul::dns_on_53`

Add firewall rules that let you hit Consul's DNS interface on the standard
port (53), without running Consul as root, and while preserving access on its
default port of 8600.

@see: https://www.consul.io/docs/guides/forwarding.html#iptables-setup

#### Examples

##### 

```puppet
# applied only on Consul servers
include haproxy_consul::dns_on_53
```

### <a name="haproxy_consulpuppet_ca_files"></a>`haproxy_consul::puppet_ca_files`

Setup connection validation via Puppet CA by copying the Puppet CA and CRL
into a place that HAProxy can access to us for connection validation

#### Examples

##### 

```puppet
include haproxy_consul::puppet_ca_files
```

#### Parameters

The following parameters are available in the `haproxy_consul::puppet_ca_files` class:

* [`haproxy_cert_dir`](#haproxy_cert_dir)
* [`puppet_ca_file_name`](#puppet_ca_file_name)
* [`puppet_crl_file_name`](#puppet_crl_file_name)

##### <a name="haproxy_cert_dir"></a>`haproxy_cert_dir`

Data type: `Stdlib::Unixpath`

The directory that will hold teh CA and CRL files
Defaults to '/etc/haproxy/certs.d'

##### <a name="puppet_ca_file_name"></a>`puppet_ca_file_name`

Data type: `String[1]`

The name to use for the CA file
Defaults to 'puppet_ca.pem'

##### <a name="puppet_crl_file_name"></a>`puppet_crl_file_name`

Data type: `String[1]`

The name to use for the CRL
Defaults to 'puppet-crl.pem'

## Defined types

### <a name="haproxy_consulresolver"></a>`haproxy_consul::resolver`

Generates a HAProxy resolver backed by Consul by querying the specified
Consul server and getting all the nodes for the service named `consul`. The
resolver will use port 8600 for DNS queries by default but that can be
overridden by crating a key named `consul-dns/port` and setting its value
to the desired port (i.e. 53).

* **See also**
  * haproxy::resolver
    * for more details on HAProxy-related parameters

#### Examples

##### 

```puppet
haproxy_consul::resolver { 'https://consul.example.com:8500': }
```

#### Parameters

The following parameters are available in the `haproxy_consul::resolver` defined type:

* [`consul_server`](#consul_server)
* [`resolver_name`](#resolver_name)
* [`resolve_retries`](#resolve_retries)
* [`timeout`](#timeout)
* [`hold`](#hold)

##### <a name="consul_server"></a>`consul_server`

Data type: `Stdlib::Httpurl`

The full url to your Consul server including protocol and port

Default value: `$title`

##### <a name="resolver_name"></a>`resolver_name`

Data type: `String[1]`

The name of the resolver that will be referenced in the balancemember's options
Defaults to 'consul'

Default value: `'consul'`

##### <a name="resolve_retries"></a>`resolve_retries`

Data type: `Integer`

Defines the number <nb> of queries to send to resolve a server name before
 giving up. Defaults to 3.

Default value: `3`

##### <a name="timeout"></a>`timeout`

Data type: `Hash`

Defines timeouts related to name resolution in the listening serivce's
 configuration block. Defaults to { 'retry' => '2s' }

Default value: `{ 'retry' => '2s' }`

##### <a name="hold"></a>`hold`

Data type: `Optional[Hash]`

Defines <period> during which the last name resolution should be kept
  based on last valid resolution status. Defaults to undef

Default value: ``undef``

### <a name="haproxy_consulserver_template"></a>`haproxy_consul::server_template`

Creating both the `haproxy::listen` and `haproxy::balancermember` for each
service you wish to use with HAProxy's 'server-template' requires a lot of
redundant code and, if you are using multi-resource declarations, can put the
two components way away from each other in your manifest. This simplifies the
process by collecting all the information that differes from service to
service and then creates the required haproxy resources.

#### Examples

##### 

```puppet
include haproxy_consul::puppet_ca_files

$_consul_domain = 'consul.example.com'
$_haproxy_cert_dir = lookup('haproxy_consul::puppet_ca_files::haproxy_cert_dir')
$_puppet_ca_file  = "${_haproxy_cert_dir}/${lookup('haproxy_consul::puppet_ca_files::puppet_ca_file_name')}"
$_puppet_crl_file = "${_haproxy_cert_dir}/${lookup('haproxy_consul::puppet_ca_files::puppet_crl_file_name')}"

haproxy_consul::server_template {
  default:
    consul_domain => $_consul_domain,
    amount        => '1',
    require       => Class['Haproxy_consul::Puppet_ca_files'],
  ;
  'pe-console-https':
    ports                  => '443',
    listen_options         => {
      'balance' => 'roundrobin',
      'option'  => [
        'ssl-hello-chk',
      ],
    },
    balancermember_options => [
      'resolvers consul',
      'resolve-prefer ipv4',
      'check',
    ],
  ;
  'pe-compiler-puppet-agent':
    ports                  => '8140',
    listen_options         => {
      'option httpchk' => 'get /status/v1/simple/master',
    },
    balancermember_options => [
      'resolvers consul',
      'resolve-prefer ipv4',
      'check check-ssl',
      'port 8140',
      'verify required',
      "ca-file ${_puppet_ca_file}",
      "crl-file ${_puppet_crl_file}",
    ],
    amount                 => '1-8',
  ;
}
```

#### Parameters

The following parameters are available in the `haproxy_consul::server_template` defined type:

* [`ports`](#ports)
* [`amount`](#amount)
* [`consul_domain`](#consul_domain)
* [`ipaddress`](#ipaddress)
* [`listen_options`](#listen_options)
* [`balancermember_options`](#balancermember_options)

##### <a name="ports"></a>`ports`

Data type: `Variant[String[1], Array[String[1]]]`

The port or ports the service listens on
Accepts either a single comma-separated string or an array of strings which
may be ports or hyphenated port ranges.

##### <a name="amount"></a>`amount`

Data type: `String[1]`

Initializes <num> servers with 1 up to <num> as server name suffixes.
A range of numbers <num_low>-<num_high> may also be used to use
<num_low> up to <num_high> as server name suffixes.

##### <a name="consul_domain"></a>`consul_domain`

Data type: `Stdlib::Fqdn`

The fqdn used by services registered in consul

##### <a name="ipaddress"></a>`ipaddress`

Data type: `String[1]`

The address to lsten on. Defaults to '*'

Default value: `'*'`

##### <a name="listen_options"></a>`listen_options`

Data type: `Optional[Hash]`

An optional hash of options for the listening service

Default value: ``undef``

##### <a name="balancermember_options"></a>`balancermember_options`

Data type: `Optional[Array[String[1]]]`

An optional hash of options for the backend balancemembers

Default value: ``undef``

